@@ -38,11 +38,13 @@ class DeepZoomGenerator(object):
     BOUNDS_SIZE_PROPS = (openslide.PROPERTY_NAME_BOUNDS_WIDTH,
                 openslide.PROPERTY_NAME_BOUNDS_HEIGHT)
 
-    def __init__(self, osr, tile_size=256, overlap=1, limit_bounds=False):
+    def __init__(self, osr, tile_size=254, overlap=1, limit_bounds=False):
         """Create a DeepZoomGenerator wrapping an OpenSlide object.
 
         osr:          a slide object.
-        tile_size:    the width and height of a single tile.
+        tile_size:    the width and height of a single tile.  For best viewer
+                      performance, tile_size + 2 * overlap should be a power
+                      of two.
         overlap:      the number of extra pixels to add to each interior edge
                       of a tile.
         limit_bounds: True to render only the non-empty slide region."""
@@ -56,6 +58,7 @@ class DeepZoomGenerator(object):
         self._osr = osr
         self._z_t_downsample = tile_size
         self._z_overlap = overlap
+        self._limit_bounds = limit_bounds
 
         # Precompute dimensions
         # Slide level and offset
@@ -110,6 +113,11 @@ class DeepZoomGenerator(object):
         self._bg_color = '#' + self._osr.properties.get(
                         openslide.PROPERTY_NAME_BACKGROUND_COLOR, 'ffffff')
 
+    def __repr__(self):
+        return '%s(%r, tile_size=%r, overlap=%r, limit_bounds=%r)' % (
+                self.__class__.__name__, self._osr, self._z_t_downsample,
+                self._z_overlap, self._limit_bounds)
+
     @property
     def level_count(self):
         """The number of Deep Zoom levels in the image."""
