@@ -19,13 +19,16 @@
 
 from functools import wraps
 import os
+from PIL import Image
 import unittest
 
+# PIL.Image cannot have zero width or height on Pillow 3.4.0 - 3.4.2
+# https://github.com/python-pillow/Pillow/issues/2259
 try:
-    import openslide._convert as _
-    have_optimizations = True
-except ImportError:
-    have_optimizations = False
+    Image.new('RGBA', (1, 0))
+    image_dimensions_cannot_be_zero = False
+except ValueError:
+    image_dimensions_cannot_be_zero = True
 
 
 def file_path(name):
